@@ -19,7 +19,7 @@
 #include "inputnumberwindow.h"
 #include "core/books.h"
 #include "commonstatic.h"
-
+#include <QTimer>
 #ifdef Q_WS_MAEMO_5
 #include "qwebviewselectionsuppressor.h"
 #include <QAbstractKineticScroller>
@@ -290,7 +290,7 @@ void BookWindow::ShowSection(int section)
             m_Fought = false;
             m_Ate = 0;
 
-            ui->scrollArea->ensureVisible(0, 0, 0, 0);            
+            QTimer::singleShot(0, this, SLOT(ScrollToTopSlot()));
             ExecuteSystemScript("EnterScript");
 
             if (!m_Section->EnterScript.isEmpty())
@@ -1093,11 +1093,13 @@ Item* BookWindow::AddHealingPickItem(QString name, int enduranceRestore)
     return NULL;
 }
 
-void BookWindow::PickItems(int max)
+int BookWindow::PickItems(int max)
 {
     PickItemsWindow* dlg = new PickItemsWindow(this, m_Player, m_PickGoldCrowns, &m_PickItems, max);
     while (dlg->exec() != QDialog::Accepted	){}
+    int picked = dlg->GetPickedItemsCount();
     delete dlg;
+    return picked;
 }
 
 int BookWindow::SelectGoldCrowns(int min)
@@ -1210,3 +1212,8 @@ int BookWindow::InputNumber(QString title, int min, int max)
     dlg->exec();
     return dlg->GetValue();
 }
+
+void BookWindow::ScrollToTopSlot()
+{
+    ui->scrollArea->ensureVisible(0, 0, 0, 0);
+}
