@@ -33,7 +33,10 @@ void ChooseItemWindow::ShowItems()
         ShowMeals();
         break;
     case ChooseItem:
-        ShowBackpackItems();
+        ShowBackpackItems(false);
+        break;
+    case ChooseItemExceptMeals:
+        ShowBackpackItems(true);
         break;
     case ChooseSpecialItem:
         ShowSpecialItems();
@@ -84,7 +87,7 @@ void ChooseItemWindow::ShowMeals()
     }
 }
 
-void ChooseItemWindow::ShowBackpackItems()
+void ChooseItemWindow::ShowBackpackItems(bool excludeMeals)
 {
     setWindowTitle("Choose an Item");
     int row=0;
@@ -94,6 +97,9 @@ void ChooseItemWindow::ShowBackpackItems()
 
     foreach(Item* i, m_Player->Items){
         if (!i->GetIsSpecial()){
+            if (excludeMeals && i->GetIsMeal())
+                continue;
+
             QLabel* lbl = new QLabel(this);
             lbl->setSizePolicy(stretchZero);
             lbl->setText(QString("<b>%1:</b>").arg(row + 1));
@@ -204,6 +210,7 @@ void ChooseItemWindow::SelectedSlot()
     {
     case ChooseMeal:
     case ChooseItem:
+    case ChooseItemExceptMeals:
     case ChooseSpecialItem:
         m_Selected = m_Player->Items.at(idx);
         break;
