@@ -29,7 +29,9 @@ private:
 
     RandomNumberPicker* m_RandomPicker;
     bool m_Close;
-    int m_PointsLost;
+    int m_PlayerDamage;
+    int m_PlayerPointsLost;
+    int m_EnemyDamage;
     int m_EnemyPointsLost;
     int m_Round;
     int m_SurpriseRound;
@@ -70,6 +72,11 @@ public slots:
     void SetSurpriseRounds(int value) { m_SurpriseRound = value; }
     int GetRandomNumber();
     void EndFight();
+    int GetPlayerDamage() { return m_PlayerDamage; }
+    void SetPlayerDamage(int value) { m_PlayerDamage = value; }
+    int GetEnemyDamage() { return m_EnemyDamage; }
+    void SetEnemyDamage(int value) { m_EnemyDamage = value; }
+
 };
 
 #endif // FIGHTWINDOW_H
